# Unofficial Public.com Invest API

This is an unofficial API for Public.com. It is a simple Python wrapper around the Public.com requests API. It is not affiliated with Public.com in any way. Use at your own risk.

This is still a very work in progress, so it might have bugs or missing features. Feel free to contribute!

## Quickstart

```bash
pip install public-invest-api
```

Then see the [examples](https://docs.nelsondane.me/public-invest-api/examples.html) for how to use the API.

## Documentation
Check out the new documentation site at [https://docs.nelsondane.me/public-invest-api/](https://docs.nelsondane.me/public-invest-api/)! It has a full API reference, examples, and more.

## Contributing
Found or fixed a bug? Have a feature request? Feel free to open an issue or pull request!

See the [contributing guide](https://docs.nelsondane.me/public-invest-api/contributing.html) for more information.

## Supporting the Project
Enjoying the project? Feel free to Sponsor me on GitHub or Ko-fi!

[![Sponsor](https://img.shields.io/badge/sponsor-30363D?style=for-the-badge&logo=GitHub-Sponsors&logoColor=#white)](https://github.com/sponsors/NelsonDane)
[![ko-fi](https://img.shields.io/badge/Ko--fi-F16061?style=for-the-badge&logo=ko-fi&logoColor=white
)](https://ko-fi.com/X8X6LFCI0)

## DISCLAIMER
DISCLAIMER: I am not a financial advisor and not affiliated with Public.com. Use this tool at your own risk. I am not responsible for any losses or damages you may incur by using this project. This tool is provided as-is with no warranty.
